import '../lib/polyfill';
import React from 'react';
import { render } from 'react-dom';
import Preview from '../components/preview';

ACMS.Dispatch.Preview = () => {
  /**
   * プレビュー
   */
  const dispatchPreviewMode = (target, url, hasCloseBtn = true, hasShareBtn = true, ready = () => {}) => {
    if (!target) {
      document.body.insertAdjacentHTML('beforeend', '<div id="acms-preview-area" style="position: fixed; top: 0; bottom: 0; left: 0; right: 0; z-index: 999;"></div>');
      target = document.querySelector('#acms-preview-area');
    }
    const htmlElement = document.querySelector('html');
    htmlElement.style.overflow = 'hidden';
    render(<Preview
      src={url}
      timemachine={false}
      hasCloseBtn={hasCloseBtn}
      hasShareBtn={hasShareBtn}
      onClose={() => {
        $(target).fadeOut('slow').queue(() => {
          target.parentNode.removeChild(target);
          htmlElement.style.overflow = '';
        });
      }}
      ready={ready}
    />, target);
  };

  /**
   * タイムマシーン
   */
  const dispatchTimemachineMode = () => {
    let area = document.querySelector('#acms-timemachine-area');
    if (!area) {
      document.body.insertAdjacentHTML('beforeend', '<div id="acms-timemachine-area" style="position: fixed; top: 0; bottom: 0; left: 0; right: 0; z-index: 999;"></div>');
      area = document.querySelector('#acms-timemachine-area');
    }
    const htmlElement = document.querySelector('html');
    htmlElement.style.overflow = 'hidden';
    render(<Preview
      timemachine
      hasCloseBtn
      onClose={() => {
        $(area).fadeOut('slow').queue(() => {
          area.parentNode.removeChild(area);
          htmlElement.style.overflow = '';
        });
      }}
    />, area);
  };

  ACMS.Ready(() => {
    const previewTarget = document.querySelector('.js-acms-preview');
    const timemachineTarget = document.querySelector('.js-acms-timemachine');
    const previewButtons = document.querySelectorAll('.js-acms-preview-button');
    // IE9以下の時は、タイムマシーン機能とプレビュー機能は使えないように調整
    if (ACMS.Dispatch.Utility.browser().ltIE9) {
      [].forEach.call(previewButtons, (button) => {
        button.style.display = 'none';
      });
      timemachineTarget.style.display = 'none';
      return;
    }
    if (previewTarget) {
      const hasShareBtn = previewTarget.getAttribute('data-share') !== '0';
      /**
       * preview mode
       */
      dispatchPreviewMode(previewTarget, previewTarget.getAttribute('data-url'), false, hasShareBtn);
    } else {
      if (previewButtons.length > 0) {
        /**
         * preview mode event
         */
        [].forEach.call(previewButtons, (button) => {
          button.addEventListener('click', () => {
            dispatchPreviewMode(null, button.getAttribute('data-url'));
          });
        });
      }
      if (!window.frameElement) {
        /**
         * timemachine mode
         */
        if (timemachineTarget) {
          timemachineTarget.addEventListener('click', dispatchTimemachineMode);
        }
        /**
         * timemachine mode event
         */
        if (ACMS.Config.timeMachineMode) {
          dispatchTimemachineMode();
        }
      }
    }
  });
};
